#ifndef __JOBWIDGET_H
#define __JOBWIDGET_H

#include <QTreeWidget>
#include <QPointer>

#include <fly-admin-printer_export.h>

class QAction;
class QEvent;
class QTimer;

namespace Cups
{
class HTTP;
}

class FLY_ADMIN_PRINTER_EXPORT JobWidget: public QTreeWidget
{
    Q_OBJECT
    QPointer<Cups::HTTP> connection;
    QString printer;

public:
    QAction *aPlay;
    QAction *aAbort;
    QAction *aRestart;
    QAction *aMove;
    QAction *aShowCompleted;
    QAction *aShowCanceled;

    JobWidget(QWidget *parent = 0);
    ~JobWidget();
    void load(QPointer<Cups::HTTP> connection, const QString &printer = QString::null);
public slots:
    virtual void currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*);
    virtual void reload();
    virtual void cancelJob();
    virtual void playJob();
    virtual void restartJob();
    virtual void showCompleted();
    virtual void showCanceled();
protected:
    virtual bool eventFilter(QObject *o, QEvent *e);
    void connectToDBus();
    void disconnectFromDBus();
protected slots:
    void jobQueuedLocal(const QString&, quint32, const QString&);
    void jobStartedLocal(const QString&, quint32, const QString&);
signals:
    void jobsStateChanged();
private:
    QTimer *refreshTimer;
};

#endif
